/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.security.idm;

/**
 * This service provides access to LoginProviders and Provisioning Providers registered with the SSO system.<br/><br/>
 * 
 * LoginProvider - provides an abstraction for Identity Stores to extract Identity data related to authentication on the system.<br/><br/>
 * 
 * ProvisioningProvider - provides an abstraction for Identity Stores to extract Identity data related to Profile Management of users in the system.<br/><br/>
 * 
 * The next release of SSO system will rely on ProvisioningProvider extensively to perform Federation User Provisioning for data stored in scattered Identity Stores.
 * 
 * @author Sohil Shah - sohil.shah@jboss.com - May 29, 2006
 *
 */
public interface IdentityManagerService 
{
    /**
     * Sets the location where the configuration for this service can be looked up
     * 
     * @param confLocation
     */
    public void setConf(String confLocation);
    
    /**
     * Returns the default LoginProvider registered with the service
     * 
     * @return
     * @throws IdentityException
     */
    public LoginProvider getLoginProvider() throws IdentityException;
    
    /**
     * Returns the LoginProvider corresponding to its registration id
     * 
     * @param id a unique id to identify the LoginProvider being registered. Must start with si:
     * @return
     */
    public LoginProvider getLoginProvider(String id) throws IdentityException;
    
    /**
     * Returns the default ProvisioningProvider registered with the service
     * 
     * @return
     * @throws IdentityException
     */
    public ProvisioningProvider getProvisioningProvider() throws IdentityException;
    
    /**
     * Returns the ProvisioningProvider corresponding to its registration id
     * 
     * @param id a unique id to identify the ProvisioningProvider being registered. Must start with si:
     * @return
     */
    public ProvisioningProvider getProvisioningProvider(String id) throws IdentityException;
}
