/*
* JBoss, Home of Professional Open Source
* Copyright 2005, JBoss Inc., and individual contributors as indicated
* by the @authors tag. See the copyright.txt in the distribution for a
* full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.security.valve;

import java.io.Serializable;
import java.security.Principal;

import javax.servlet.http.HttpSession;

//jboss-sso framework libraries
import org.jboss.security.saml.SingleSignOn;

/**
 * @author Sohil Shah - sohil.shah@jboss.com
 *
 */
public class SSOSession implements Serializable
{
    /**
     * 
     */
    private String context = null;
    private Principal principal = null; //principal for which automatic sso session has been created
    private Boolean turnOff = null; //tells the SSOEngine to not do any automatic sso logins
    private Boolean monitor = null; //tells the SSOEngine that there is currently an active sso session established for this user
    private boolean forceLogout = false;
    
    

    /**
     * 
     */
    public SSOSession()
    {
        
    }

    /**
     * 
     * @return
     */
    public Boolean getTurnOff() 
    {
        return turnOff;
    }


    /**
     * 
     * @param turnOff
     */
    public void setTurnOff(Boolean turnOff) 
    {
        this.turnOff = turnOff;
    }


    /**
     * 
     * @return
     */
    public Principal getPrincipal() 
    {
        return principal;
    }
    
    /**
     * 
     * @return
     */
    public String getContext()
    {
        return this.context;
    }
    
    /**
     * 
     * @param context
     * @param principal
     */
    public void setPrincipal(String context,Principal principal)
    {
       this.context = context;
       this.principal = principal;
    }
    
    /**
     * 
     * @return
     */
    public Boolean getMonitor() 
    {
        return monitor;
    }

    /**
     * 
     * @param monitor
     */
    public void setMonitor(Boolean monitor) 
    {
        this.monitor = monitor;
    }
    
    /**
     * 
     * @return
     */
    public String getUsername()
    {
        String username = null;
        
        if(this.principal!=null)
        {
            username = this.principal.getName();
        }
        
        return username;
    }
    
    /**
     * 
     * @param session
     * @return
     */
    public void reset()
    {
        this.context = null;
        this.principal = null;
        this.turnOff = null;
        this.monitor = null;
    }
    
    
    /**
     * 
     * @return
     */
    public boolean getForceLogout() 
    {
        return forceLogout;
    }

    /**
     * 
     * @param forceLogout
     */
    public void setForceLogout(boolean forceLogout) 
    {
        this.forceLogout = forceLogout;
    }

    /**
     * 
     * @param session
     * @return
     */
    public static SSOSession getSSOSession(HttpSession session)
    {
        SSOSession ssoSession = null;
        
        ssoSession = (SSOSession)session.getAttribute(SingleSignOn.SSO_SESSION);
        if(ssoSession==null)
        {
            ssoSession = new SSOSession();
            session.setAttribute(SingleSignOn.SSO_SESSION,ssoSession);
        }
        
        return ssoSession;
    }
    
    /**
     * 
     * @param session
     * @return
     */
    public static void clearSSOSession(HttpSession session)
    {
        session.removeAttribute(SingleSignOn.SSO_SESSION);        
    }
}
